@@ -86,20 +86,20 @@ class TeamServiceHttpRequestHandler(HttpRequestHandler):
     def get_member(self, request, team_id, account_id):
         return TeamService().get_member(request.app_id, request.account_id, team_id, account_id)
 
-    @http_request(r'^/team/(team_id:uuid)/member$',
-                  http_method=HttpMethod.GET,
-                  authentication_required=True)
-    def get_members(self, request, team_id):
-        offset = request.get_argument('offset',
-                data_type=HttpRequest.ArgumentDataType.integer,
-                is_required=False,
-                default_value=0)
-        limit = request.get_argument('limit',
-                data_type=HttpRequest.ArgumentDataType.integer,
-                is_required=False,
-                default_value=TeamService.DEFAULT_LIMIT)
-        return TeamService().get_members(request.app_id, request.account_id, team_id,
-                offset=offset, limit=limit)
+    # @http_request(r'^/team/(team_id:uuid)/member$',
+    #               http_method=HttpMethod.GET,
+    #               authentication_required=True)
+    # def get_members(self, request, team_id):
+    #     offset = request.get_argument('offset',
+    #             data_type=HttpRequest.ArgumentDataType.integer,
+    #             is_required=False,
+    #             default_value=0)
+    #     limit = request.get_argument('limit',
+    #             data_type=HttpRequest.ArgumentDataType.integer,
+    #             is_required=False,
+    #             default_value=TeamService.DEFAULT_LIMIT)
+    #     return TeamService().get_members(request.app_id, request.account_id, team_id,
+    #             offset=offset, limit=limit)
 
     @http_request(r'^/team$',
                   http_method=HttpMethod.GET,
